@@ -5,8 +5,9 @@ use Carp;
 use strict;
 use warnings;
 use List::Util 1.45 qw /uniq/;
+use Scalar::Util qw /blessed/;
 
-our $VERSION = 0.002;
+our $VERSION = 0.003;
 
 #no autovivification;
 
@@ -45,7 +46,7 @@ sub new {
 
 sub clone {
     my $self = shift;
-    my $cloned = $self->new ();
+    my $cloned = bless [], blessed $self;
     $cloned->[_ARRAY] = [@{$self->[_ARRAY]}];
     $cloned->[_HASH]  = {%{$self->[_HASH]}};
     return $cloned;
